==> org.apache.sling.scripting.thymeleaf-1.1.0-source-release.zip: org.apache.sling.scripting.thymeleaf-1.1.0/src/test/java/org/apache/sling/scripting/thymeleaf/it/tests/html/LinkBuilderIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.scripting.thymeleaf.it.tests.html;

import java.io.IOException;

import org.apache.sling.scripting.thymeleaf.it.tests.ThymeleafTestSupport;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.ops4j.pax.exam.junit.PaxExam;
import org.ops4j.pax.exam.spi.reactors.ExamReactorStrategy;
import org.ops4j.pax.exam.spi.reactors.PerClass;

import static org.hamcrest.Matchers.is;
import static org.junit.Assert.assertThat;

@RunWith(PaxExam.class)
@ExamReactorStrategy(PerClass.class)
public class LinkBuilderIT extends ThymeleafTestSupport {

    private Document document;

    @Before
    public void setup() throws IOException {
        final String url = String.format("http://localhost:%s/thymeleaf/link.html", httpPort());
        document = Jsoup.connect(url).get();
    }

    @Test
    public void testFooLink() throws IOException {
        final Element link = document.getElementById("foo");
        assertThat(link.attributes().get("href"), is("foobar"));
    }

    @Test
    public void testBarLink() throws IOException {
        final Element link = document.getElementById("bar");
        assertThat(link.attributes().get("href"), is("bar"));
    }

}

==> org.apache.sling.scripting.thymeleaf-2.0.2-source-release.zip: org.apache.sling.scripting.thymeleaf-2.0.2/src/test/java/org/apache/sling/scripting/thymeleaf/it/tests/html/LinkBuilderIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.scripting.thymeleaf.it.tests.html;

import java.io.IOException;

import org.apache.sling.scripting.thymeleaf.it.tests.ThymeleafTestSupport;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.ops4j.pax.exam.junit.PaxExam;
import org.ops4j.pax.exam.spi.reactors.ExamReactorStrategy;
import org.ops4j.pax.exam.spi.reactors.PerClass;

import static org.hamcrest.Matchers.is;
import static org.junit.Assert.assertThat;

@RunWith(PaxExam.class)
@ExamReactorStrategy(PerClass.class)
public class LinkBuilderIT extends ThymeleafTestSupport {

    private Document document;

    @Before
    public void setup() throws IOException {
        final String url = String.format("http://localhost:%s/thymeleaf/link.html", httpPort());
        document = Jsoup.connect(url).get();
    }

    @Test
    public void testFooLink() throws IOException {
        final Element link = document.getElementById("foo");
        assertThat(link.attributes().get("href"), is("foobar"));
    }

    @Test
    public void testBarLink() throws IOException {
        final Element link = document.getElementById("bar");
        assertThat(link.attributes().get("href"), is("/thymeleaf/bar"));
    }

}
